function metropolis(action)
%
% Programm fuer das 2D Ising Modell   
% 
% Author:  Winfried Kernbichler,Dieter Mayer
% Version: 1.0 
% Date:    23. Januar 2002
% Status:  erste Schritte
% Missing:  


% Test of all gui_routines

% ==========================================================================
% ==========================================================================
% one should keep this at the beginning of the file
% just change func_name
func_name = 'metropolis';                    % function name - same as declaration
% ==========================================================================
handle_name = [func_name,'_HANDLE'];  % name of global variable, erzeugt den String: gol_Handle
eval(['global ',handle_name]);        % set it global
if nargin == 0, action = 'initgraph'; end  % set to initgraph without input, wenn keine Eingabeparameter existieren
if ~strcmp(action,'initgraph'),       % vergleicht die Action mit dem Wort initgraph
    eval(['HANDLE=',handle_name,';']);  % copy global to local
else                                  % wenn die Aktion initgraph ist
    % one can change this strings, Grundeinstellungen
    logo_switch = 1;                  % logo: yes (1), no (0)
    fig_title   = 'Metropolis & Simulated Tempering';
    logo_title  = 'Metropolis & Simulated Tempering';
    logo_name   = ' Dieter Mayer, Wolfgang von der Linden, Hans Gerd Evertz, Winfried Kernbichler ';
    logo_lv     = 'Multimediale Lehre';
    logo_type   = 'logo_1';           % only this is defined at the moment
    min_par     = 1;                  % minimum fuer Parallelwerte
    max_par     = 20;                 % maximum fuer Parallelwerte
    sta_par     = 1;                  % standard fuer Parallelwerte
    min_iter    = 1000;               % minimum fuer iterationen
    max_iter    = 1000000;            % maximum fuer iterationen
    sta_iter    = 1000;               % standard fuer iterationen
    min_beta    = 1;                  % minimale Anzahl der beta_Niveaus
    max_beta    = 30;                 % maximale Anzahl der beta_Niveaus
    sta_beta    = 10;                 % Standardeinstellung Anzahl der beta_Niveaus
    min_zell    = 20;                 % minimale Anzahl der beta_Niveaus
    max_zell    = 500;                % maximale Anzahl der beta_Niveaus
    sta_zell    = 100;                % Standardeinstellung Anzahl der beta_Niveaus
    sta_x_min   = 0;                  % Standardeinstellung fuer untere x-Grenze
    sta_x_max   = 10;                 % Standardeinstellung fuer obere x-Grenze
    sta_y_min   = 0;                  % Standardeinstellung fuer untere y-Grenze
    sta_y_max   = 10;                 % Standardeinstellung fuer obere y-Grenze
    min_temp    = 1;               % minimum fuer iterationen
    max_temp    = 10;            % maximum fuer iterationen
    sta_temp    = 1;               % standard fuer iterationen
  
    sta_f_name  = 'funktion_1';       % Standardeinstellung fuer Funktionsname 
    % some colors
    ax_color = [0.9,0.9,0.9];         % default axes color
    bo_color = [0.6,0.6,0.6];         % default border color
    % do not change
    HANDLE = [];                      % empty at the beginning
end
% ==========================================================================
% ==========================================================================
% Here every aspect of the graphics part should be handled
% This contains the definition and the callback routines
switch lower(action)
    % ========================================================================
    % initialization of program
case 'initgraph'    
    % ----------------------------------------------------------------------
    % preprocessing for initgraph (keep this lines) 
    eval( [func_name,' ''initgraph_pre'''] );
    % ----------------------------------------------------------------------
    
    % ---------------------------------------------------------------------- 
    % definition and creation of graphics objects
    % ----------------------------------------------------------------------
    
    % ----------------------------------------------------------------------  
    % definition of main figure
    % ----------------------------------------------------------------------  
    F.figure = struct( ...
        'frame',    { [0.0, 0.0, 1.0, 1.0] }, ...   %Haupt-Frame soll ganzen Bildschrim ausfuellen
        'geometry', { [1] }, ...                    %nur ein Fenster
        'closerequestfcn', { 'close_request_main' }, ...        
        'renderer', { 'opengl' }, ...
        'name',     { fig_title }, ...
        'tag',      { 'main' } ...                  %Kennzeichnung, um figure wiederzuerkennen
        );
    % --- should be kept ---------------------------------------------------  
    [HANDLE,fig_han] = gui_create(gui_define(F),HANDLE); % creation
    clear F;                                      % not needed any more
    % add function name to tag and closerequestfcn
    % important for finding program related figures and to find function
    gui_add_name(fig_han,func_name,'_','b','tag');
    gui_add_name(fig_han,func_name,' ','b','closerequestfcn');
    % sets necessary userdata for figures
    gui_set_userdata(fig_han, ...
        'function',func_name, ...
        'end','exit');
    figmain_han = fig_han;
    % figure color
    fig_color = get( ...
        gui_handle_query(HANDLE.figure,'tag','*main*'),'color');
    % ----------------------------------------------------------------------
    
    % ----------------------------------------------------------------------  
    % create meta frames, Erschaffung der 5 Bildschirm
    % ----------------------------------------------------------------------  
    if logo_switch
        logo_y_pos  = 0.9; % y division between logo and rest
    else
        logo_y_pos  = 1.0;
    end
    meta_frame_logo   = [0, logo_y_pos, 1, 1-logo_y_pos]; % logo
    meta_frame_layer1 = [0, 0,          1, logo_y_pos  ]; % layer 1   
    % ----------------------------------------------------------------------  
    
    % ----------------------------------------------------------------------  
    % create logo
    % ----------------------------------------------------------------------
    if logo_switch
        % --------------------------------------------------------------------  
        logo_string = {logo_title,logo_name,logo_lv};
        logo_parent = figmain_han;
        % here one could use HANDLE instead of HANDLE_LOGO, then one could 
        % refere to all contents within the rest of the program.
        % When using HANDLE_LOGO this graphics part stays seperate. 
        HANDLE_LOGO = [];
        HANDLE_LOGO = gui_create_logo(HANDLE_LOGO, logo_string, ...
            logo_parent, meta_frame_logo, logo_type);
    end
    % ----------------------------------------------------------------------  
    % ----------------------------------------------------------------------  
    
    % ---------------------------------------------------------------------- 
    % create main frames at 4 positions
    %  four joined parts with division lines given at 
    %  x: x_div_pos y: y_div_pos
    % ----------------------------------------------------------------------  
    mf = meta_frame_layer1;    % choose meta frame
    x_div_pos = 0.80 * mf(3);  % division line in x direction
    y_div_pos = 0.20 * mf(4);  % division line in y direction
    % frames for lower-left, lower-right, upper-left, upper-right
    ll_frame = [ mf(1), mf(2), 0.5*mf(3), y_div_pos ];
    lr_frame = [ 0.8*mf(3), mf(2) , 0.2*mf(3), y_div_pos ];
    lm_frame = [ 0.5*mf(3), mf(2) , 0.3*mf(3), y_div_pos ];
    ur1_frame = [ 0.8*mf(3), 0.88*mf(4), 0.2*mf(3), 0.12*mf(4) ];
    ur4_frame = [ 0.8*mf(3), 0.78*mf(4), 0.2*mf(3), 0.10*mf(4) ];
    ur2_frame = [ 0.8*mf(3), 0.35*mf(4), 0.2*mf(3), 0.43*mf(4) ];
    ur3_frame = [ 0.8*mf(3), 0.2*mf(4), 0.2*mf(3), 0.15*mf(4) ];

    ul_frame = [ mf(1), 0.2*mf(4), 0.8*mf(3), 0.8*mf(4)];
    
    % ----------------------------------------------------------------------  
    % definition of some basis axes system for the background of all four
    % parts defined in the meta frame.
    Fbasis.axes = struct( ...
        'geometry', { [1] }, ...
        'xborder',  { [0.0, 0.0] }, ...
        'yborder',  { [0.0, 0.0] }, ...
        'xgap',     { [0.0] }, ...
        'ygap',     { [0.0] }, ...	
        'parent',   { [1] }, ...
        'visible',  { 'on' }, ...
        'box',      { 'on' }, ...
        'xtick',    { [] }, ...
        'ytick',    { [] }, ...
        'color',    { ax_color }, ...
        'xcolor',   { bo_color }, ...
        'ycolor',   { bo_color } ...	
        );
    
    % ----------------------------------------------------------------------  
    % lower left position (containing sliders)
    % ---------------------------------------------------------------------- 
    % basic axis for background
    Fbasis.axes = setfield(Fbasis.axes,'frame',ll_frame );
    Fbasis.axes = setfield(Fbasis.axes,'tag','base_axes');
    [HANDLE,newh] = gui_create(gui_define(Fbasis),HANDLE);
    gui_add_name(newh,'lower_left',' ','b','tag');            
    
    % definitions of slider values
    geom = [ 1, 1; 1, 1 ];
    % typical values
    visible = { 'on', 'on',;'on',  'on'  };
    minval  = { min_iter, min_beta; min_par, min_zell }; % minimum
    maxval  = { max_iter, max_beta; max_par, max_zell }; % maximum
    svalue  = { sta_iter, sta_beta; sta_par, sta_zell  }; % value for slider
    evalue = svalue;                            % value for edit (string)
    for k = 1:length(svalue(:)), evalue{k} = num2str(svalue{k}); end
    
    %tag = 'slider'; Sliderbezeichnung, zugleich Variablen Name
    cab = 'set_value';
    str = { ...
            'Iterations','Beta_number';'Parallel','Hist-Cells'};
    tag = lower(str);
    % create variables from string
    var = transpose(flipud(lower(str))); % variables
    % here transpose and flipud is necessary to allow later use with
    % gui_add_userdata 
    % graphics obejects are counted from lower left corner along the 
    % second dimension, arrays and cells from upper left corner along
    % the first dimension.
    % The command lower is used to make sure variable names are lower
    % case.
    
    % callback action to be performed, fragt, ob bei Betaetigung die Graphik erneuert werden muss
    cb_ac = ''; cb_no = '';
    cbaction = { cb_no, cb_no; cb_no, cb_no};
    
    cbaction = transpose(flipud(lower(cbaction)));
    % what should be changed in the slider, rundet Sliderwerte auf ganze (bzw gerade) Zahlen
    cb_ch1 = { 'value','round(##)' }; cb_ch2 = { 'value','round(10^(##))' };cb_no = {};
    cbchange_sl = { cb_ch1, cb_ch1; cb_ch1, cb_ch1}; 
    cbchange_sl = transpose(flipud(cbchange_sl));
    % what should be changed in the edit field, rundet Werte in den Edit-Feldern auf ganze bzw. gerade Zahlen
    cb_ch1 = { 'string','num2str((round(str2num(##))))' };cb_ch2 = { 'string','num2str(round(log10(str2num(##))))' };cb_no = {};
    cbchange_ed = { cb_ch1, cb_ch1; cb_ch1, cb_ch1};
    
    cbchange_ed = transpose(flipud(cbchange_ed));
    % what should be updated when slider changes, see also updatehandle, Edit-Felder -> Slider
    update_sl = { { 'value','string','num2str((##))' } };
    update_sl = transpose(flipud(update_sl));
    % what should be updated when edit changes, see also updatehandle, Slider -> Edit-Felder    
    update_ed = { { 'string','value','str2num((##))' } };
    update_ed = transpose(flipud(update_ed));
    
    %Struktur fuer Slider
    Fu.uicontrol = struct( ...
        'frame',         { ll_frame }, ...
        'geometry',      { geom }, ...
        'xborder',       { [0.05, 0.05] }, ...
        'yborder',       { [0.1, 0.3] }, ...
        'xgap',          { [0.05] }, ...
        'ygap',          { [0.3] }, ...
        'xshift',        { [0.0] }, ...	
        'yshift',        { [0.0] }, ...	
        'xmodify',       { 'size' }, ...
        'parent',        { [1] }, ...
        'style',         { 'slider' }, ...
        'min',           { minval }, ...
        'max',           { maxval }, ...
        'value',         { svalue }, ...
        'visible',       { visible }, ...
        'interruptible', { 'off' }, ...
        'fontsize',      { 1 }, ...
        'string',        { str }, ...
        'callback',      { cab }, ...
        'tag',           { tag } ...
        );
    [HANDLE,slider_han] = gui_create(gui_define(Fu),HANDLE);
    % sets variable name in userdata + action and update information
    gui_set_userdata(slider_han,'variable',var); 
    gui_set_userdata(slider_han,'cbaction',cbaction);
    gui_set_userdata(slider_han,'cbchange',cbchange_sl);
    gui_set_userdata(slider_han,'updateproperty',update_sl); 
    gui_add_name(slider_han,'value',' ','e','tag');    
    gui_add_name(slider_han,'slider',' ','e','tag');    

    % add edit field shifted above (look for 'yshift')
    Fu.uicontrol = setfield(Fu.uicontrol,'xmodify',             'left');
    Fu.uicontrol = setfield(Fu.uicontrol,'xsize',               0.15);
    Fu.uicontrol = setfield(Fu.uicontrol,'yshift',              0.20);
    Fu.uicontrol = setfield(Fu.uicontrol,'style',               'edit');
    Fu.uicontrol = setfield(Fu.uicontrol,'horizontalalignment', 'left');    
    Fu.uicontrol = setfield(Fu.uicontrol,'string',              evalue);    
    Fu.uicontrol = setfield(Fu.uicontrol,'fontsize',            0.60);
    Fu.uicontrol = setfield(Fu.uicontrol,'callback',            'edit_check');
    %Fu.uicontrol = setfield(Fu.uicontrol,'tag',                 'slider_edit');
    Fu.uicontrol = setfield(Fu.uicontrol,'backgroundcolor',     ax_color);   
    [HANDLE,edit_han] = gui_create(gui_define(Fu),HANDLE);
    % sets variable name in userdata + action and update information
    gui_set_userdata(edit_han,'variable',var); 
    gui_set_userdata(edit_han,'cbaction',cbaction);
    gui_set_userdata(edit_han,'cbchange',cbchange_ed);
    gui_set_userdata(edit_han,'updateproperty',update_ed);
    gui_set_userdata(edit_han,'callback',[func_name,' ',cab]);
    gui_add_name(edit_han,'slider_edit',' ','e','tag');    
    
    % add text shifted above 
    Fu.uicontrol = setfield(Fu.uicontrol,'xmodify',             'right');
    Fu.uicontrol = setfield(Fu.uicontrol,'xsize',               0.25);
    Fu.uicontrol = setfield(Fu.uicontrol,'style',               'text');
    Fu.uicontrol = setfield(Fu.uicontrol,'horizontalalignment', 'right');    
    Fu.uicontrol = setfield(Fu.uicontrol,'string',              str);    
    Fu.uicontrol = setfield(Fu.uicontrol,'fontsize',            0.8);
    Fu.uicontrol = setfield(Fu.uicontrol,'callback',            '');
    %Fu.uicontrol = setfield(Fu.uicontrol,'tag',                 'slider_text');
    Fu.uicontrol = setfield(Fu.uicontrol,'backgroundcolor',     ax_color);   
    [HANDLE,text_han] = gui_create(gui_define(Fu),HANDLE);
    gui_add_name(text_han,'slider_text',' ','e','tag');    
    
    % updatehandle for slider (handles of edit)
    edit_cell = mat2cell(edit_han,1,ones(size(edit_han)));
    gui_set_userdata(slider_han,'updatehandle',edit_cell); 
    % updatehandle for edit (handles of slider)
    slider_cell = mat2cell(slider_han,1,ones(size(slider_han)));
    gui_set_userdata(edit_han,'updatehandle',slider_cell); 
    % adds function name to callback    
    gui_add_name([slider_han,edit_han],func_name,' ','b','callback');
    % adds common name to tag
    gui_add_name([slider_han,edit_han,text_han],'lower_left',' ','b','tag');
    % clears structur Fu    
    clear Fu
    
    % ----------------------------------------------------------------------  
    % lower middle position (containing editfields)
    % ---------------------------------------------------------------------- 
    % basic axis for background
    Fbasis.axes = setfield(Fbasis.axes,'frame',lm_frame );
    Fbasis.axes = setfield(Fbasis.axes,'tag','base_axes');
    [HANDLE,newh] = gui_create(gui_define(Fbasis),HANDLE);
    gui_add_name(newh,'lower_middle',' ','b','tag');            
    
    % definitions of slider values
    geom = [ 1, 1; 1, 1 ];
    % typical values
    visible = { 'on', 'on',;'on',  'on'  };
    svalue  = { sta_x_min, sta_x_max; sta_y_min, sta_y_max}; % value for edit
    for k = 1:length(svalue(:)), evalue{k} = num2str(svalue{k}); end
    
    cab = '';
    str = { ...
            'x_min','x_max';'y_min','y_max'};
    tag = lower(str);
    % create variables from string
    var = transpose(flipud(lower(str))); % variables
    
    % callback action to be performed, fragt, ob bei Betaetigung die Graphik erneuert werden muss
    cb_ac = ''; cb_no = '';
    cbaction = { cb_no, cb_no; cb_no, cb_no};
    
    cbaction = transpose(flipud(lower(cbaction)));
    
    %Struktur fuer edit
    Fu.uicontrol = struct( ...
        'frame',         { lm_frame }, ...
        'geometry',      { geom }, ...
        'xborder',       { [0.05, 0.05] }, ...
        'yborder',       { [0.1, 0.3] }, ...
        'xgap',          { [0.05] }, ...
        'ygap',          { [0.3] }, ...
        'xshift',        { [0.0] }, ...	
        'yshift',        { [0.0] }, ...	
        'xmodify',       { 'size' }, ...
        'parent',        { [1] }, ...
        'style',         { 'edit' }, ...
        'visible',       { visible }, ...
        'interruptible', { 'off' }, ...
        'fontsize',      { 0.6 }, ...
        'string',        { evalue }, ...
        'callback',      { cab }, ...
        'tag',           { tag } ...
        );
    [HANDLE,edit_grenz_han] = gui_create(gui_define(Fu),HANDLE);
    % sets variable name in userdata + action and update information
    gui_set_userdata(edit_grenz_han,'variable',var);               
    gui_add_name(edit_grenz_han,'edit_grenz_text',' ','e','tag');    

    % add text shifted above 
    Fu.uicontrol = setfield(Fu.uicontrol,'xmodify',             'right');
    Fu.uicontrol = setfield(Fu.uicontrol,'xsize',               0.25);
    Fu.uicontrol = setfield(Fu.uicontrol,'style',               'text');
    Fu.uicontrol = setfield(Fu.uicontrol,'yshift',              0.20);
    Fu.uicontrol = setfield(Fu.uicontrol,'horizontalalignment', 'right');    
    Fu.uicontrol = setfield(Fu.uicontrol,'string',              str);    
    Fu.uicontrol = setfield(Fu.uicontrol,'fontsize',            0.8);
    Fu.uicontrol = setfield(Fu.uicontrol,'callback',            '');
    %Fu.uicontrol = setfield(Fu.uicontrol,'tag',                 'slider_text');
    Fu.uicontrol = setfield(Fu.uicontrol,'backgroundcolor',     ax_color);   
    [HANDLE,text_grenz_han] = gui_create(gui_define(Fu),HANDLE);
    gui_add_name(text_grenz_han,'grenz_text',' ','e','tag');    
    
    % adds common name to tag
    gui_add_name([edit_grenz_han,edit_han,text_han],'lower_left',' ','b','tag');
    % clears structur Fu    
    clear Fu
    
    % ----------------------------------------------------------------------  
    % lower right position, enthaelt Hilfe, Exit, Start und Stop Buttons
    % ----------------------------------------------------------------------  
    % basic axis for background
    Fbasis.axes = setfield(Fbasis.axes,'frame',lr_frame );
    Fbasis.axes = setfield(Fbasis.axes,'tag','base_axes');
    [HANDLE,newh] = gui_create(gui_define(Fbasis),HANDLE);
    gui_add_name(newh,'lower_right',' ','b','tag');            
    
    % ----------------------------------------------------------------------  
    % define uicontrol pushbutton
    geom = [1,1 ; 1,1];
    str = reshape({ 'Start','Help', 'Stop', 'Exit'},size(geom));
    tag = lower(str);
    cab = lower(str);
    
    F.uicontrol = struct( ...
        'frame',    { lr_frame }, ...
        'geometry', { geom }, ...
        'parent',   { [1] }, ...
        'style',    { 'pushbutton' }, ...
        'visible',  { 'on' }, ...
        'fontsize', { 0.35 }, ...
        'string',   { str }, ...
        'callback', { cab }, ...
        'tag',      { tag } ...
        );
    [HANDLE,newh] = gui_create(gui_define(F),HANDLE); clear F;
    gui_add_name(newh,func_name,' ','b','callback');
    gui_add_name(newh,'lower_right',' ','b','tag');            
    % settings for stop handle
    stop_handle = gui_handle_query(newh,'tag','*stop');
    gui_set_userdata(stop_handle,'stop',0);
    set(stop_handle,'enable','off');
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % ----------------------------------------------------------------------  
    % upper left position, enthaelt die Graphiken
    % ----------------------------------------------------------------------

    
    Fbasis.axes = setfield(Fbasis.axes,'frame',ul_frame );
    Fbasis.axes = setfield(Fbasis.axes,'tag','base_axes');
    [HANDLE,newh] = gui_create(gui_define(Fbasis),HANDLE);    
    gui_add_name(newh,'upper_left',' ','b','tag');            

    % ----------------------------------------------------------------------  
    % add axes 
    geom = [1];
    tag  = {'p_verteilung'};

    F.axes = struct( ...
	'frame',    { ul_frame }, ...
	'geometry', { geom }, ...
    'xgap',     { [0.05] }, ...
	'ygap',     { [0.05] }, ...
	'parent',   { [1] }, ...
    'fontsize', {0.035},...
	'visible',  { 'on' }, ...
	'box',      { 'off' }, ...
	'tag',      { tag } ...	
	);
  

    [HANDLE,axes_vert_h] = gui_create(gui_define(F),HANDLE);clear F;
    gui_add_name(axes_vert_h,'result','_','b','tag');
    gui_add_name(axes_vert_h,'upper_left',' ','b','tag');
    
    xlabel('x','fontunits','normalized','fontsize',0.05);    
    ylabel('y','fontunits','normalized','fontsize',0.05);
    zlabel('z','fontunits','normalized','fontsize',0.05);
    title('Distribution of Probability','fontunits','normalized','fontsize',0.05);

    grid on
    colormap hsv

    % add lines to axes (p_verteilung)
    vert_h     = gui_handle_query(axes_vert_h,'tag','*p_vert*');
    tag       = { 'p_verteilung'};
    markerstyle = { 'none' };
    markersize  = {  2 };
    GUI.surface  = struct( 'parent', { vert_h }, ...
	'tag',              tag, ...
    'buttondownfcn',    {'rotate3d on;waitforbuttonpress;waitforbuttonpress;rotate3d off'}...
	);
    [HANDLE,surf_vert_h] = gui_create(GUI,HANDLE); clear GUI
    shading interp
    zlim([0,1]);
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % 2.Achse fuer Sim-Temp
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    geom = [1];
    tag  = {'sim_temp'};

    F.axes = struct( ...
	'frame',    { ul_frame }, ...
	'geometry', { geom }, ...
    'xgap',     { [0.05] }, ...
	'ygap',     { [0.05] }, ...
	'parent',   { [1] }, ...
    'fontsize', { 0.03},...
	'visible',  { 'off' }, ...
	'box',      { 'off' }, ...
	'tag',      { tag } ...	
	);
  
    [HANDLE,axes_simtemp_h] = gui_create(gui_define(F),HANDLE);clear F;
    gui_add_name(axes_simtemp_h,'result','_','b','tag');
    gui_add_name(axes_simtemp_h,'upper_left',' ','b','tag');

    xlabel('x','fontunits','normalized','fontsize',0.05);    
    ylabel('y','fontunits','normalized','fontsize',0.05);
    zlabel('P(x,y)','fontunits','normalized','fontsize',0.05);
    title('red: beta = 1,....,purple: beta = 0','fontunits','normalized','fontsize',0.05);

    grid on

    % add lines to axes (sim_temp)
    simtemp_h     = gui_handle_query(axes_simtemp_h,'tag','*sim_temp*');
    tag       = { 'sim_temp'};
    markerstyle = { 'none' };
    markersize  = {  2 };
    GUI.surface  = struct( 'parent', { simtemp_h }, ...
	'tag',              tag, ...
    'visible',          'off',...
    'buttondownfcn',    {'rotate3d on;waitforbuttonpress;waitforbuttonpress;rotate3d off'}...
	);
    [HANDLE,surf_simtemp_h] = gui_create(GUI,HANDLE); clear GUI
    shading interp
    zlim([0,1]); 
    
    %%%%%%%%%%%%%%%%%%  Plot3d fuer Ergebnisse des Simulated Temperings

    
    % add lines to axes 
    l3d_h     = gui_handle_query(axes_simtemp_h,'tag','*sim_temp*');
    tag       = { 'sim_temp_line','sim_temp_line', 'sim_temp_line','sim_temp_line','sim_temp_line','sim_temp_line',...
                  'sim_temp_line','sim_temp_line', 'sim_temp_line','sim_temp_line', 'sim_temp_line','sim_temp_line',...
                  'sim_temp_line','sim_temp_line', 'sim_temp_line','sim_temp_line','sim_temp_line','sim_temp_line',...
                  'sim_temp_line','sim_temp_line', 'sim_temp_line','sim_temp_line', 'sim_temp_line','sim_temp_line',...
                  'sim_temp_line','sim_temp_line', 'sim_temp_line','sim_temp_line', 'sim_temp_line','sim_temp_line'};
    col       = { 'b'};
    linestyle   = { '.' };
    linewidth = { 2 }; 
    markerstyle = { '*' };
    markersize  = {  2 };
    GUI.line  = struct( 'parent', { l3d_h }, ...
	'xdata',     { [] }, ...
	'ydata',     { [] }, ...
 	'zdata',     { [] }, ...
	'linewidth', linewidth, ...
    'linestyle',    linestyle, ...
	'marker',       markerstyle, ...
	'markersize',   markersize, ...
	'erasemode',  'normal', ...
	'color',     col, ...
	'tag',       tag ...
	);
   
    [HANDLE,line_3d_h] = gui_create(GUI,HANDLE); clear GUI
           
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % 3.Achse fuer beta_Histogramm
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    geom = [1];
    tag  = {'beta_hist'};

    F.axes = struct( ...
	'frame',    { ul_frame }, ...
	'geometry', { geom }, ...
    'xgap',     { [0.05] }, ...
	'ygap',     { [0.05] }, ...
	'parent',   { [1] }, ...
    'fontsize', { 0.03},...
	'visible',  { 'off' }, ...
	'box',      { 'off' }, ...
	'tag',      { tag } ...	
	);
  
    [HANDLE,axes_betahist_h] = gui_create(gui_define(F),HANDLE);clear F;
    gui_add_name(axes_betahist_h,'result','_','b','tag');
    gui_add_name(axes_betahist_h,'upper_left',' ','b','tag');

    xlabel('Beta','fontunits','normalized','fontsize',0.05);
    ylabel('frequency','fontunits','normalized','fontsize',0.05);
    title('distribution of Beta','fontunits','normalized','fontsize',0.05);
    
    % add patches to axes (beta_hist)
    betahist_h     = gui_handle_query(axes_betahist_h,'tag','*beta_hist*');
    tag       = { 'beta_hist'};
    
    GUI.patch  = struct( 'parent', { betahist_h }, ...
	'tag',              tag, ...
  	'xdata',            [], ...
	'ydata',            [], ...
    'visible',          'off',...
    'buttondownfcn',    {'rotate3d off'}...
	);
    [HANDLE,patch_betahist_h] = gui_create(GUI,HANDLE); clear GUI
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % 4. und 5. Achse fuer 1D_Histogramm
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    geom = [1;1];
    tag  = {'hist_1d1';'hist_1d2'};

    F.axes = struct( ...
	'frame',    { ul_frame }, ...
	'geometry', { geom }, ...
    'xgap',     { [0.05] }, ...
	'ygap',     { [0.05] }, ...
	'parent',   { [1] }, ...
    'fontsize', { 0.03},...
	'visible',  { 'off' }, ...
	'box',      { 'off' }, ...
	'tag',      { tag } ...	
	);
  
    [HANDLE,axes_hist1d_h] = gui_create(gui_define(F),HANDLE);clear F;
    gui_add_name(axes_hist1d_h,'result','_','b','tag');
    gui_add_name(axes_hist1d_h,'upper_left',' ','b','tag');

    title('Histogram for the parameters x and y ','fontsize',18);
    % add patches to axes (hist1d1)
    hist1d1_h     = gui_handle_query(axes_hist1d_h,'tag','*hist_1d1*');
    tag       = { 'hist_1d1'};
    
    GUI.patch  = struct( 'parent', { hist1d1_h }, ...
	'tag',              tag, ...
  	'xdata',            [], ...
	'ydata',            [], ...
    'visible',          'off',...
    'buttondownfcn',    {'rotate3d off'}...
	);
    [HANDLE,patch_hist1d1_h] = gui_create(GUI,HANDLE); clear GUI


    % add patches to axes (hist1d2)
    hist1d2_h     = gui_handle_query(axes_hist1d_h,'tag','*hist_1d2*');
    tag       = { 'hist_1d2'};
    
    GUI.patch  = struct( 'parent', { hist1d2_h }, ...
	'tag',              tag, ...
  	'xdata',            [], ...
	'ydata',            [], ...
    'visible',          'off',...
    'buttondownfcn',    {'rotate3d off'}...
	);
    [HANDLE,patch_hist1d2_h] = gui_create(GUI,HANDLE); clear GUI

    Fbasis.axes = setfield(Fbasis.axes,'frame',ul_frame );
    Fbasis.axes = setfield(Fbasis.axes,'tag','base_axes');
    [HANDLE,newh] = gui_create(gui_define(Fbasis),HANDLE);    
    gui_add_name(newh,'upper_left',' ','b','tag');            


    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % 6. Achse fuer 2D_Histogramm
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    geom = [1];
    tag  = {'hist_2d'};

    F.axes = struct( ...
	'frame',    { ul_frame }, ...
	'geometry', { geom }, ...
    'xgap',     { [0.05] }, ...
	'ygap',     { [0.05] }, ...
	'parent',   { [1] }, ...
    'fontsize', {0.03},...
	'visible',  { 'on' }, ...
	'box',      { 'off' }, ...
	'tag',      { tag } ...	
	);
  

    [HANDLE,axes_hist2d_h] = gui_create(gui_define(F),HANDLE);clear F;
    gui_add_name(axes_hist2d_h,'result','_','b','tag');
    gui_add_name(axes_hist2d_h,'upper_left',' ','b','tag');
    
    xlabel('x','fontunits','normalized','fontsize',0.05);    
    ylabel('y','fontunits','normalized','fontsize',0.05);
    zlabel('frequency','fontunits','normalized','fontsize',0.05);
    title('Histogram for the parameters x and y','fontunits','normalized','fontsize',0.05);
    
    grid on
    colormap hsv

    % add lines to axes (p_verteilung)
    hist_2d     = gui_handle_query(axes_hist2d_h,'tag','*hist_2d*');
    tag       = { 'hist_2d'};
    markerstyle = { 'none' };
    markersize  = {  2 };
    GUI.surface  = struct( 'parent', { hist_2d }, ...
	'tag',              tag, ...
    'buttondownfcn',    {'rotate3d on;waitforbuttonpress;waitforbuttonpress;rotate3d off'}...
	);
    [HANDLE,surf_hist2d_h] = gui_create(GUI,HANDLE); clear GUI
    shading interp
                                                      
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % 7. Achse fuer die Ergebnisse
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    geom = [1];
    tag  = {'results'};

    F.axes = struct( ...
	'frame',    { ul_frame }, ...
	'geometry', { geom }, ...
    'xgap',     { [0.05] }, ...
	'ygap',     { [0.05] }, ...
    'color',   { ax_color }, ...
    'xcolor',   { ax_color }, ...
    'ycolor',   { ax_color }, ...
	'parent',   { [1] }, ...
    'fontsize', {0.03},...
	'visible',  { 'on' }, ...
	'box',      { 'off' }, ...
	'tag',      { tag } ...	
	);
  

    [HANDLE,axes_results_h] = gui_create(gui_define(F),HANDLE);clear F;
    gui_add_name(axes_results_h,'result','_','b','tag');
    gui_add_name(axes_results_h,'upper_left',' ','b','tag');


    results = gui_handle_query(axes_results_h,'tag','*results*');


    
    geom = [2,2,2,2,2,2,2,2,2,2,2,2;...
            4,4,11,12,13,14,15,16,17,18,19,20;...
            5,5,21,22,23,24,25,26,27,28,29,30;...
            6,6,31,32,33,34,35,36,37,38,39,40;...
            3,3,3,3,3,3,3,3,3,3,3,3;...
            7,7,41,42,43,44,45,46,47,48,49,50;...
            8,8,51,52,53,54,55,56,57,58,59,60;...
            9,9,61,62,63,64,65,66,67,68,69,70];
    tag = reshape({ 'hx','hx','hx','hx','hx','hx','hx','hx','hx','hx','hx','hx';...
            'gewichtx','gewichtx','gx','gx','gx','gx','gx','gx','gx','gx','gx','gx';...
            'mittelx','mittelx','mx','mx','mx','mx','mx','mx','mx','mx','mx','mx';...
            'standx','standx','sx','sx','sx','sx','sx','sx','sx','sx','sx','sx';...
            'hy','hy','hy','hy','hy','hy','hy','hy','hy','hy','hy','hy';...
            'gewichty','gewichty','gy','gy','gy','gy','gy','gy','gy','gy','gy','gy';...
            'mittely','mittely','my','my','my','my','my','my','my','my','my','my';...
            'standy','standy','sy','sy','sy','sy','sy','sy','sy','sy','sy','sy'},size(geom));
    %Struktur fuer static-text
    Fu.uicontrol = struct( ...
        'parent',          { 1 }, ...
        'frame',           { ul_frame }, ...
        'geometry',        { geom }, ...
        'xborder',         { [0.0, 0.0] }, ...
        'yborder',         { [0.0, 0.05] }, ...  
        'xshift',          { [0.0] }, ...	
        'yshift',          { [0.0] }, ...	
        'ysize',           { [0.2] }, ...	
        'xgap',            { [0.005] }, ...
        'ygap',            { [0.03] }, ...        
        'xmodify',         { 'size' }, ...
        'style',           { 'text' }, ...
        'fontsize',        { 0.35 }, ...
        'backgroundcolor', { 'w' }, ...
        'visible',         { 'off'}, ...
        'tag',             { tag } ...
        );
    [HANDLE,xy_han] = gui_create(gui_define(Fu),HANDLE); 
    gui_add_name(xy_han,'ergebnisse','_','b','tag');

    
    
    
    
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % 8.Achse fuer Animation-Points
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    geom = [1];
    tag  = {'anim_points'};

    F.axes = struct( ...
	'frame',    { ul_frame }, ...
	'geometry', { geom }, ...
    'xgap',     { [0.05] }, ...
	'ygap',     { [0.05] }, ...
	'parent',   { [1] }, ...
    'fontsize', { 0.03},...
	'visible',  { 'off' }, ...
	'box',      { 'off' }, ...
	'tag',      { tag } ...	
	);
  
    [HANDLE,axes_animpoints_h] = gui_create(gui_define(F),HANDLE);clear F;
    gui_add_name(axes_animpoints_h,'result','_','b','tag');
    gui_add_name(axes_animpoints_h,'upper_left',' ','b','tag');
    
    xlabel('x','fontunits','normalized','fontsize',0.05);    
    ylabel('y','fontunits','normalized','fontsize',0.05);
    zlabel('P(x,y)','fontunits','normalized','fontsize',0.05);
    title('red: beta = 1,....,purple: beta = 0','fontunits','normalized','fontsize',0.05);

    grid on

    % add lines to axes (sim_temp) (Animation-points)
    animpoints_h     = gui_handle_query(axes_animpoints_h,'tag','*anim_points*');
    tag       = { 'anim_points'};
    markerstyle = { 'none' };
    markersize  = {  2 };
    GUI.surface  = struct( 'parent', { animpoints_h }, ...
	'tag',              tag, ...
    'visible',          'off',...
    'buttondownfcn',    {'rotate3d on;waitforbuttonpress;waitforbuttonpress;rotate3d off'}...
	);
    [HANDLE,surf_animpoints_h] = gui_create(GUI,HANDLE); clear GUI
    shading interp
    zlim([0,1]); 
    
    %%%%%%%%%%%%%%%%%%  Plot3d fuer Ergebnisse des Simulated Temperings (Animation)

    
    % add lines to axes 
    l3danim_h     = gui_handle_query(axes_animpoints_h,'tag','*anim_points*');
    tag       = { 'anim_points_line'};
    
    col       = { 'b'};
    linestyle   = { '.' };
    linewidth = { 2 }; 
    markerstyle = { '*' };
    markersize  = {  3 };
    GUI.line  = struct( 'parent', { l3danim_h }, ...
	'xdata',     { [] }, ...
	'ydata',     { [] }, ...
 	'zdata',     { [] }, ...
	'linewidth', linewidth, ...
    'linestyle',    linestyle, ...
	'marker',       markerstyle, ...
	'markersize',   markersize, ...
	'erasemode',  'none', ...
	'color',     col, ...
	'tag',       tag ...
	);
   
    [HANDLE,line_3danim_h] = gui_create(GUI,HANDLE); clear GUI                                  
    
    
    
     
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % 9.Achse fuer Animation-Steps
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    geom = [1];
    tag  = {'anim_steps'};

    F.axes = struct( ...
	'frame',    { ul_frame }, ...
	'geometry', { geom }, ...
    'xgap',     { [0.05] }, ...
	'ygap',     { [0.05] }, ...
	'parent',   { [1] }, ...
    'fontsize', { 0.03},...
	'visible',  { 'off' }, ...
	'box',      { 'off' }, ...
	'tag',      { tag } ...	
	);
  
    [HANDLE,axes_animsteps_h] = gui_create(gui_define(F),HANDLE);clear F;
    gui_add_name(axes_animsteps_h,'result','_','b','tag');
    gui_add_name(axes_animsteps_h,'upper_left',' ','b','tag');
    
    xlabel('x','fontunits','normalized','fontsize',0.05);    
    ylabel('y','fontunits','normalized','fontsize',0.05);
    zlabel('P(x,y)','fontunits','normalized','fontsize',0.05);
    title('red: beta = 1,....,purple: beta = 0','fontunits','normalized','fontsize',0.05);

    grid on

    % add lines to axes (sim_temp) (Animation-steps)
    animsteps_h     = gui_handle_query(axes_animsteps_h,'tag','*anim_steps*');
    tag       = { 'anim_steps'};
    markerstyle = { 'none' };
    markersize  = {  2 };
    GUI.surface  = struct( 'parent', { animsteps_h }, ...
	'tag',              tag, ...
    'visible',          'off',...
    'buttondownfcn',    {'rotate3d on;waitforbuttonpress;waitforbuttonpress;rotate3d off'}...
	);
    [HANDLE,surf_animsteps_h] = gui_create(GUI,HANDLE); clear GUI
    shading interp
    zlim([0,1]); 
    
    %%%%%%%%%%%%%%%%%%  Plot3d fuer Ergebnisse des Simulated Temperings (Animation-steps)

    
    % add lines to axes 
    l3danim2_h     = gui_handle_query(axes_animsteps_h,'tag','*anim_steps*');
    tag       = { 'anim_steps_line','anim_steps_line','anim_steps_line','anim_steps_line','anim_steps_line',...
            'anim_steps_line','anim_steps_line','anim_steps_line','anim_steps_line','anim_steps_line',...
            'anim_steps_line','anim_steps_line','anim_steps_line','anim_steps_line','anim_steps_line',...
            'anim_steps_line','anim_steps_line','anim_steps_line','anim_steps_line','anim_steps_line',...
            'anim_steps_line','anim_steps_line','anim_steps_line','anim_steps_line','anim_steps_line',...
            'anim_steps_line','anim_steps_line','anim_steps_line','anim_steps_line','anim_steps_line'};
    
    col       = { 'b'};
    linestyle   = { '.' };
    linewidth = { 2 }; 
    markerstyle = { '*' };
    markersize  = {  5 };
    GUI.line  = struct( 'parent', { l3danim2_h }, ...
	'xdata',     { [] }, ...
	'ydata',     { [] }, ...
 	'zdata',     { [] }, ...
	'linewidth', linewidth, ...
    'linestyle',    linestyle, ...
	'marker',       markerstyle, ...
	'markersize',   markersize, ...
	'erasemode',  'none', ...
	'color',     col, ...
	'tag',       tag ...
	);
   
    [HANDLE,line_3danim2_h] = gui_create(GUI,HANDLE); clear GUI                                  
 
    
    
    
    %----------------------------------------------------------------------  
    % ----------------------------------------------------------------------  
    % upper right1 position
    % ----------------------------------------------------------------------  
    % basic axis for background
    Fbasis.axes = setfield(Fbasis.axes,'frame',ur1_frame );
    Fbasis.axes = setfield(Fbasis.axes,'tag','base_axes');

    [HANDLE,funk_han] = gui_create(gui_define(Fbasis),HANDLE);
    gui_add_name(funk_han,'upper_right1',' ','b','tag');            
      
    geom = [1];
    % typical values
    visible = { 'on'};
    evalue  = sta_f_name; % value for edit
    
    cab = '';
    str = { ...
            'Function-name'};
    tag = lower(str);
    % create variables from string
    var = transpose(flipud(lower(str))); % variables
    
    % callback action to be performed, fragt, ob bei Betaetigung die Graphik erneuert werden muss
    cb='funk_callback';cb_no = '';
    cbaction = { cb};
    
    cbaction = transpose(flipud(lower(cbaction)));
    
    %Struktur fuer edit
    Fu.uicontrol = struct( ...
        'frame',         { ur1_frame }, ...
        'geometry',      { geom }, ...
        'xborder',       { [0.05, 0.05] }, ...
        'yborder',       { [0.2, 0.5] }, ...
        'xgap',          { [0.05] }, ...
        'ygap',          { [0.5] }, ...
        'xshift',        { [0.0] }, ...	
        'yshift',        { [0.0] }, ...	
        'ysize',         { [0.2] }, ...	
        'xmodify',       { 'size' }, ...
        'parent',        { [1] }, ...
        'style',         { 'edit' }, ...
        'visible',       { visible }, ...
        'interruptible', { 'off' }, ...
        'fontsize',      { 0.7 }, ...
        'string',        { evalue }, ...
        'callback',      { cb }, ...
        'tag',           { tag } ...
        );
    [HANDLE,funk_han] = gui_create(gui_define(Fu),HANDLE);
    % sets variable name in userdata + action and update information
    gui_set_userdata(funk_han,'variable',var);               
    gui_add_name(funk_han,'Funktionsname',' ','e','tag');    
    gui_add_name(funk_han,func_name,' ','b','callback');

    % add text shifted above 
%    Fu.uicontrol = setfield(Fu.uicontrol,'xmodify',             'right');
    Fu.uicontrol = setfield(Fu.uicontrol,'xsize',               0.45);
    Fu.uicontrol = setfield(Fu.uicontrol,'style',               'text');
    Fu.uicontrol = setfield(Fu.uicontrol,'yshift',              0.30);
    Fu.uicontrol = setfield(Fu.uicontrol,'horizontalalignment', 'center');    
    Fu.uicontrol = setfield(Fu.uicontrol,'string',              str);    
    Fu.uicontrol = setfield(Fu.uicontrol,'fontsize',            0.7);
    Fu.uicontrol = setfield(Fu.uicontrol,'callback',            '');
    %Fu.uicontrol = setfield(Fu.uicontrol,'tag',                 'slider_text');
    Fu.uicontrol = setfield(Fu.uicontrol,'backgroundcolor',     ax_color);   
    [HANDLE,text_funk_han] = gui_create(gui_define(Fu),HANDLE);
    gui_add_name(text_funk_han,'edit_funk_text',' ','e','tag');    
    
    % adds common name to tag
    gui_add_name([funk_han,text_funk_han],'upper_right1',' ','b','tag');
    % clears structur Fu    
    clear Fu
    
    
    
    
    
    % ----------------------------------------------------------------------  
    % upper right4 position
    % ----------------------------------------------------------------------  
    % basic axis for background
    
    % basic axis for background
    Fbasis.axes = setfield(Fbasis.axes,'frame',ur4_frame );
    Fbasis.axes = setfield(Fbasis.axes,'tag','base_axes');
    [HANDLE,newh] = gui_create(gui_define(Fbasis),HANDLE);
    gui_add_name(newh,'upper_right4',' ','b','tag');            
    
    % definitions of slider values
    geom = [ 1];
    % typical values
    visible = { 'on'};
    minval  = { min_temp}; % minimum
    maxval  = { max_temp}; % maximum
    svalue  = { sta_temp}; % value for slider
    evalue = svalue;                            % value for edit (string)
    for k = 1:length(svalue(:)), evalue{k} = num2str(svalue{k}); end
    
    %tag = 'slider'; Sliderbezeichnung, zugleich Variablen Name
    cab = 'set_value';
    str = { ...
            'Beta'};
    tag = lower(str);
    % create variables from string
    var = transpose(flipud(lower(str))); % variables
       
    % callback action to be performed, fragt, ob bei Betaetigung die Graphik erneuert werden muss
    cb_ac = 'exp_verteilung'; cb_no = '';
    cbaction = {cb_ac};
    
    cbaction = transpose(flipud(lower(cbaction)));
    % what should be changed in the slider, rundet Sliderwerte auf ganze (bzw gerade) Zahlen
    cb_ch1 = { 'value','round(##)' };
    cbchange_sl = { cb_ch1}; 
    cbchange_sl = transpose(flipud(cbchange_sl));
    % what should be changed in the edit field, rundet Werte in den Edit-Feldern auf ganze bzw. gerade Zahlen
    cb_ch1 = { 'string','num2str((round(str2num(##))))' };
    cbchange_ed = { cb_ch1};
    
    cbchange_ed = transpose(flipud(cbchange_ed));
    % what should be updated when slider changes, see also updatehandle, Edit-Felder -> Slider
    update_sl = { { 'value','string','num2str((##))' } };
    update_sl = transpose(flipud(update_sl));
    % what should be updated when edit changes, see also updatehandle, Slider -> Edit-Felder    
    update_ed = { { 'string','value','str2num((##))' } };
    update_ed = transpose(flipud(update_ed));
    
    %Struktur fuer Slider
    Fu.uicontrol = struct( ...
        'frame',         { ur4_frame }, ...
        'geometry',      { geom }, ...
        'xborder',       { [0.1, 0.1] }, ...
        'yborder',       { [0.1, 0.5] }, ...
        'xgap',          { [0.05] }, ...
        'ygap',          { [0.3] }, ...
        'xshift',        { [0.0] }, ...	
        'yshift',        { [0.0] }, ...	
        'xmodify',       { 'size' }, ...
        'parent',        { [1] }, ...
        'style',         { 'slider' }, ...
        'min',           { minval }, ...
        'max',           { maxval }, ...
        'value',         { svalue }, ...
        'visible',       { visible }, ...
        'enable',        { 'off' }, ...
        'interruptible', { 'off' }, ...
        'fontsize',      { 0.8 }, ...
        'string',        { str }, ...
        'callback',      { cab }, ...
        'tag',           { tag } ...
        );
    [HANDLE,slider_han] = gui_create(gui_define(Fu),HANDLE);
    % sets variable name in userdata + action and update information
    gui_set_userdata(slider_han,'variable',var); 
    gui_set_userdata(slider_han,'cbaction',cbaction);
    gui_set_userdata(slider_han,'cbchange',cbchange_sl);
    gui_set_userdata(slider_han,'updateproperty',update_sl); 
    gui_add_name(slider_han,'slider',' ','e','tag');    
    
    % add edit field shifted above (look for 'yshift')
    Fu.uicontrol = setfield(Fu.uicontrol,'xmodify',             'left');
    Fu.uicontrol = setfield(Fu.uicontrol,'xsize',               0.20);
    Fu.uicontrol = setfield(Fu.uicontrol,'yshift',              0.42);
    Fu.uicontrol = setfield(Fu.uicontrol,'style',               'edit');
    Fu.uicontrol = setfield(Fu.uicontrol,'horizontalalignment', 'left');    
    Fu.uicontrol = setfield(Fu.uicontrol,'string',              evalue);    
    Fu.uicontrol = setfield(Fu.uicontrol,'fontsize',            0.5);
    Fu.uicontrol = setfield(Fu.uicontrol,'callback',            'edit_check');
    %Fu.uicontrol = setfield(Fu.uicontrol,'tag',                 'slider_edit');
    Fu.uicontrol = setfield(Fu.uicontrol,'backgroundcolor',     ax_color);   
    [HANDLE,edit_han] = gui_create(gui_define(Fu),HANDLE);
    % sets variable name in userdata + action and update information
    gui_set_userdata(edit_han,'variable',var); 
    gui_set_userdata(edit_han,'cbaction',cbaction);
    gui_set_userdata(edit_han,'cbchange',cbchange_ed);
    gui_set_userdata(edit_han,'updateproperty',update_ed);
    gui_set_userdata(edit_han,'callback',[func_name,' ',cab]);
    gui_add_name(edit_han,'slider_edit',' ','e','tag');    
    
    
     % add text field shifted above for the value of beta
    Fu.uicontrol = setfield(Fu.uicontrol,'xmodify',             'right');
    Fu.uicontrol = setfield(Fu.uicontrol,'xsize',               0.20);
    Fu.uicontrol = setfield(Fu.uicontrol,'yshift',              0.42);
    Fu.uicontrol = setfield(Fu.uicontrol,'style',               'text');
    Fu.uicontrol = setfield(Fu.uicontrol,'horizontalalignment', 'right');    
    Fu.uicontrol = setfield(Fu.uicontrol,'string',              '1');    
    Fu.uicontrol = setfield(Fu.uicontrol,'fontsize',            0.5);
    %Fu.uicontrol = setfield(Fu.uicontrol,'tag',                 'slider_edit');
    Fu.uicontrol = setfield(Fu.uicontrol,'backgroundcolor',     ax_color);   
    [HANDLE,edit2_han] = gui_create(gui_define(Fu),HANDLE);
    % sets variable name in userdata + action and update information
    gui_add_name(edit2_han,'upper_right4',' ','b','tag');            
    gui_add_name(edit2_han,'value',' ','e','tag');    
 
    
    
    % add text shifted above 
    Fu.uicontrol = setfield(Fu.uicontrol,'xmodify',             'center');
    Fu.uicontrol = setfield(Fu.uicontrol,'xsize',               0.20);
    Fu.uicontrol = setfield(Fu.uicontrol,'style',               'text');
    Fu.uicontrol = setfield(Fu.uicontrol,'horizontalalignment', 'right');    
    Fu.uicontrol = setfield(Fu.uicontrol,'string',              str);    
    Fu.uicontrol = setfield(Fu.uicontrol,'fontsize',            0.6);
    Fu.uicontrol = setfield(Fu.uicontrol,'callback',            '');
    %Fu.uicontrol = setfield(Fu.uicontrol,'tag',                 'slider_text');
    Fu.uicontrol = setfield(Fu.uicontrol,'backgroundcolor',     ax_color);   
    [HANDLE,text_han] = gui_create(gui_define(Fu),HANDLE);
    gui_add_name(text_han,'slider_text',' ','e','tag');    
    
    % updatehandle for slider (handles of edit)
    edit_cell = mat2cell(edit_han,1,ones(size(edit_han)));
    gui_set_userdata(slider_han,'updatehandle',edit_cell); 
    % updatehandle for edit (handles of slider)
    slider_cell = mat2cell(slider_han,1,ones(size(slider_han)));
    gui_set_userdata(edit_han,'updatehandle',slider_cell); 
    % adds function name to callback    
    gui_add_name([slider_han,edit_han],func_name,' ','b','callback');
    % adds common name to tag
    gui_add_name([slider_han,edit_han,text_han],'upper_right4',' ','b','tag');
    % clears structur Fu    
    clear Fu   
  
    
    
    % ----------------------------------------------------------------------  
    % upper right2 position
    % ----------------------------------------------------------------------  
    % basic axis for background
    Fbasis.axes = setfield(Fbasis.axes,'frame',ur2_frame );
    Fbasis.axes = setfield(Fbasis.axes,'tag','base_axes');

    [HANDLE,newh] = gui_create(gui_define(Fbasis),HANDLE);
    gui_add_name(newh,'upper_right2',' ','b','tag');            
    
    
    geom = ones(7,1);
    str = reshape({ 'P-Distribution', 'Sim-Tempering','Beta-Histogram', '1D-Histogram', '2D-Histogram', 'Results','Smooth-Hist.'},size(geom));
    sty=reshape({ 'pushbutton','pushbutton','pushbutton','pushbutton','pushbutton','pushbutton','pushbutton'},size(geom));
    tag = lower(str);
    
    cab1  = 'plot_wahr';cab2 = 'sim_tempering';cab3 = 'beta_histogramm';cab4 = 'd1_histogramm';
    cab5  = 'd2_histogramm'; cab6 = 'results'; cab7 = 'smooth_histogramm';
    cab  = reshape({ cab1, cab2, cab3, cab4, cab5, cab6, cab7}, size(geom));
    ena  = reshape({ 'on', 'off', 'off', 'off', 'off', 'off', 'off'}, size(geom));
   
    % typical values
    visible = reshape({ 'on','on','on','on','on','on','off'}, size(geom));;
    
       % create variables from string
    var = transpose(flipud(lower(str))); % variables

    cbaction = transpose(flipud(lower(cbaction)));
    
    %Struktur fuer pushbutton
   
    Fpush.uicontrol = struct( ...
	'frame',    { ur2_frame }, ...
	'geometry', { geom }, ...
	'yborder',  { [0.05,0.05] }, ...
	'ygap',     { [0.02] }, ...
	'parent',   { [1] }, ...
	'style',    { sty }, ...
	'visible',  { 'on'}, ...
  	'enable',   { ena}, ...
	'fontsize', { 0.45 }, ...
	'string',   { str }, ...
	'callback', { cab }, ...
	'tag',      { tag } ...
	);
    [HANDLE,newh] = gui_create(gui_define(Fpush),HANDLE); clear Fpush;
    gui_add_name(newh,func_name,' ','b','callback');
    gui_add_name(newh,'upper_right2',' ','b','tag');
  

    % ----------------------------------------------------------------------  
    % upper right3 position
    % ----------------------------------------------------------------------  
    % basic axis for background
    Fbasis.axes = setfield(Fbasis.axes,'frame',ur3_frame );
    Fbasis.axes = setfield(Fbasis.axes,'tag','base_axes');

    [HANDLE,newh] = gui_create(gui_define(Fbasis),HANDLE);
    gui_add_name(newh,'upper_right3',' ','b','tag');            
    
    
    geom = ones(2,1);
    str = reshape({ 'Animation-Points', 'Animation-Steps'},size(geom));
    sty=reshape({ 'pushbutton','pushbutton'},size(geom));
    tag = lower(str);
    
    cab1 = 'animation_points';cab2 = 'animation_steps';
    cab  = reshape({ cab1, cab2}, size(geom));
    
   
    % typical values
    visible = { 'on'};
    
       % create variables from string
    var = transpose(flipud(lower(str))); % variables

    cbaction = transpose(flipud(lower(cbaction)));
    
    %Struktur fuer pushbutton
   
    Fpush.uicontrol = struct( ...
	'frame',    { ur3_frame }, ...
	'geometry', { geom }, ...
	'yborder',  { [0.12,0.12] }, ...
	'ygap',     { [0.04] }, ...
	'parent',   { [1] }, ...
	'style',    { sty }, ...
	'visible',  { 'on'}, ...
    'enable',   { 'off'}, ...
	'fontsize', { 0.4 }, ...
	'string',   { str }, ...
	'callback', { cab }, ...
	'tag',      { tag } ...
	);
    [HANDLE,newh] = gui_create(gui_define(Fpush),HANDLE); clear Fpush;
    gui_add_name(newh,func_name,' ','b','callback');
    gui_add_name(newh,'upper_right3',' ','b','tag');
    
        % ----------------------------------------------------------------------  
    
    % ----------------------------------------------------------------------  
    % keep this here to setup first image 
    % ----------------------------------------------------------------------  
    eval( [handle_name,'=HANDLE;'] );
    eval( [func_name,' ''plot_wahr'''] );
    
    % ----------------------------------------------------------------------  
    % postprocessing for initgraph (keep this lines)
    % ----------------------------------------------------------------------  
    eval( [func_name,' ''initgraph_post'''] );
    % ----------------------------------------------------------------------  
    
    % ----------------------------------------------------------------------  
    % set main figure to visible on (keep this lines)   
    % ----------------------------------------------------------------------  
    fig_han = eval([handle_name,'.figure']);   % get content of figure
    fig_han = gui_handle_query(fig_han,'tag',['*main']);
    set(fig_han,'visible','on');          % set figures to visible
    % ======================================================================
case 'initgraph_pre'               
    % preprocessing for initgraph (keep this lines)    
    % ======================================================================
    gui_default('set') % default values
    % close figures belonging to this program
    fig_han = get(0,'children');   
    fig_han = gui_handle_query(fig_han, ...
        'type','figure','tag',[func_name,'*']);
    delete(fig_han);
    % ======================================================================
    
case 'initgraph_post'               
    % postprocessing for initgraph (keep this lines)   
    % ======================================================================
    gui_default('remove'); % reset defaults to MATLAB defaults
    % ======================================================================
    
case 'exit'
    % finishing the program (keep this lines)
    % ========================================================================
    fig_han = eval([handle_name,'.figure']); % get all figures
    fig_han = fig_han(ishandle(fig_han));    % check if exist as handle
    delete(fig_han);                         % closes all figures
    clear('global',handle_name)              % deletes the global variable
    % ======================================================================
    
case 'close_request_main'  
    % close request main (keep this lines)
    % ======================================================================
    func = gui_get_userdata(gcf,'function'); % function name
    exit = gui_get_userdata(gcf,'end');      % action for exit
    msg = { ...
            ['Closing this figure exits program ',func,'.']; ...
            'Do you really want to exit?' ...
        };
    tit = 'Close Request Function';
    selection = questdlg(msg,tit,'Yes','No','Yes');
    switch selection,
    case 'Yes',
        eval( [func,' ',exit] )
    case 'No'
        return
    end
    % ======================================================================
    
case 'close_request_help'  
    % close request for help (keep this lines)
    % ======================================================================
    func = gui_get_userdata(gcf,'function');
    exit = gui_get_userdata(gcf,'end');
    msg = { ...
            'Closing this figure is not possible.'; ...
            'Do you want to make it invisible?' ...
        };
    tit = 'Close Request Function';
    selection = questdlg(msg,tit,'Yes','No','Yes');
    switch selection,
    case 'Yes',
        eval( [func,' ',exit] )
    case 'No'
        return
    end    
    % ======================================================================
    
case 'help'
    % calling help
    % ======================================================================
    frame = [0.1, 0.1, 0.8, 0.5];
    [HANDLE,new] = gui_help(HANDLE,frame,func_name);
    if new, eval([handle_name,'=HANDLE;']); end % export to global
    % ======================================================================
    
case 'edit_check'
    % checks string from edit field
    % ======================================================================
    str    = get(gcbo,'string');
    oldval = get(gcbo,'value');
    % if strcmp(gui_get_userdata(gcbo,'variable'),'iterations')
    %     minval = round(10^get(gcbo,'min'));
    %     maxval = round(10^get(gcbo,'max'));
    % else
    minval = get(gcbo,'min');
    maxval = get(gcbo,'max');
    % end    
    val = str2num(str);
    % handle all error cases
    if ~isempty(val)
        if val<minval
            msg = { 'Value too small!','Value set to minimum.' };
            e_han = msgbox(msg,'Edit Box','error','modal');
            set(gcbo,'string',num2str(minval));
        elseif val>maxval
            msg = { 'Value too large!','Value set to maximum.' };
            e_han = msgbox(msg,'Edit Box','error','modal');
            %e_han = errordlg(msg,'Edit Box','on');
            set(gcbo,'string',num2str(maxval));
        end
    else
        msg = { 'Wrong value!','Value set to old value.' };
        e_han = msgbox(msg,'Edit Box','error','modal');
        %e_han = errordlg(msg,'Edit Box','on');
        if isfield(get(gcbo,'userdata'),'updatehandle')
            updatehandle   = gui_get_userdata(gcbo,'updatehandle');      
            updateproperty = gui_get_userdata(gcbo,'updateproperty');
            oldval = get(updatehandle,updateproperty{2});
        end
        set(gcbo,'string',num2str(oldval));
    end
    
    % do the real callback
    if isfield(get(gcbo,'userdata'),'callback')
        eval( gui_get_userdata(gcbo,'callback') );
    end
    % ======================================================================
    
    
    
    
    
    
case 'set_value'
    % get values from caller 
    % ======================================================================
    e_str  = gui_get_userdata(gcbo,'variable');
    cbaction = gui_get_userdata(gcbo,'cbaction');
    figure_han = get(gcbo,'parent');
    func_name = gui_get_userdata(figure_han,'function');
    
    parallel = get(gui_handle_query(HANDLE.uicontrol,'tag','*parallel value*'),'value');    
    iterationen = get(gui_handle_query(HANDLE.uicontrol,'tag','*iterations value*'),'value');
    
    set(gui_handle_query(HANDLE.uicontrol,'tag','*iterations value*'),...
        'value',min(iterationen,round(1000000/parallel)),'max',round(1000000/parallel))
    
    if iterationen*parallel>1000000
       iterationen=1000000/parallel;
    end
    set(gui_handle_query(HANDLE.uicontrol,'tag','*iterations slider_edit*'),'string',num2str(round(iterationen)))



    if isfield(get(gcbo,'userdata'),'cbchange')
        cbchange = gui_get_userdata(gcbo,'cbchange');
        if ~isempty(cbchange)
            prop = cbchange{1};
            chfunc = cbchange{2};
            e_str = [ 'get(gcbo,''',prop,''')' ];
            e_str = strrep(chfunc,'##',e_str);
            e_str = [ 'set(gcbo,''',prop,''',',e_str,');' ];
            eval( e_str );
        end
    end
    
    % do the update of another handle
    if isfield(get(gcbo,'userdata'),'updatehandle')
        updatehandle   = gui_get_userdata(gcbo,'updatehandle');      
        updateproperty = gui_get_userdata(gcbo,'updateproperty');      
        if ~isempty(updatehandle)
            from_prop = updateproperty{1};
            to_prop   = updateproperty{2};
            chfunc    = updateproperty{3};
            e_str = [ 'get(gcbo,''',from_prop,''')' ];
            e_str = strrep(chfunc,'##',e_str);
            e_str = [ 'set(updatehandle,''',to_prop,''',',e_str,');' ];
            eval( e_str );
        end
    end
    
    if ~isempty(cbaction)
        eval( [func_name,' ',cbaction] );
    end
    
    
    
    % ======================================================================

    % ======================================================================
case 'stop'
    % stop
    % ======================================================================
    stop_han = gui_handle_query(HANDLE.uicontrol,'tag','*stop');    
    gui_set_userdata(stop_han,'stop',1);
    % ======================================================================

case 'wahr_verteilung'    
    
    han_surf=HANDLE.surface;
    surf_pvert_han = gui_handle_query(han_surf,'tag','*p_verteilung*');
       
    ui_han=HANDLE.uicontrol;
    funk_han = gui_handle_query(ui_han,'tag','*Funktionsname*');
    funk_name = get(funk_han,'string');
    
    grenz_han = gui_handle_query(ui_han,'tag','*edit_grenz*');
    x_min = str2num(get(gui_handle_query(grenz_han,'tag','*x_min*'),'string'));
    x_max = str2num(get(gui_handle_query(grenz_han,'tag','*x_max*'),'string'));
    y_min = str2num(get(gui_handle_query(grenz_han,'tag','*y_min*'),'string'));
    y_max = str2num(get(gui_handle_query(grenz_han,'tag','*y_max*'),'string'));

    vektor_x=x_min:(x_max-x_min)/200:x_max;
    vektor_y=y_min:(y_max-y_min)/200:y_max;
    
    [xx,yy]=meshgrid(vektor_x,vektor_y);

    xy=[reshape(xx,[],1),reshape(yy,[],1)];
    
    prob = exp(verteilung_fortran(xy,funk_name));
    %load prob prob
    %save prob prob
    prob = reshape(prob,[length(vektor_x),length(vektor_y)]);
    gui_set_userdata(surf_pvert_han,'x_data',xx,'y_data',yy,'z_data',prob)
    
case 'plot_wahr'    
    eval([func_name,' ','wahr_verteilung'])
    eval([func_name,' ','unsichtbar'])

    gui_set_userdata(gui_handle_query(HANDLE.uicontrol,'tag','*beta slider*'),'cbaction','exp_verteilung')
    
    alle_handle=[HANDLE.axes,HANDLE.surface,HANDLE.line,HANDLE.patch];
   
    set(gui_handle_query((alle_handle),'tag','*p_verteilung*'),'visible','on')
    axes(gui_handle_query((HANDLE.axes),'tag','*p_verteilung*'))
  
    
    han_surf=HANDLE.surface;
    surf_pvert_han = gui_handle_query(han_surf,'tag','*p_verteilung*');
    
    xx=gui_get_userdata(surf_pvert_han,'x_data');
    yy=gui_get_userdata(surf_pvert_han,'y_data');
    prob=gui_get_userdata(surf_pvert_han,'z_data');

    set(surf_pvert_han,'facecolor','texturemap','xdata',xx,'ydata',yy,'zdata',prob,'cdata',prob)
    shading interp

    xlabel('x','fontunits','normalized','fontsize',0.05);
    ylabel('y','fontunits','normalized','fontsize',0.05);
    zlabel('P(x,y)','fontunits','normalized','fontsize',0.05)
    
    axes((gui_handle_query(HANDLE.axes,'tag','*p_verteilung*')))
    colormap hsv
    % ======================================================================
case 'start'
    
    han_surf=HANDLE.surface;
    surf_pvert_han = gui_handle_query(han_surf,'tag','*p_verteilung*');
    surf_simtemp_han = gui_handle_query(han_surf,'tag','*sim_temp*');

    set(gui_handle_query(HANDLE.uicontrol,'tag','*beta slider'),'value',1)
    set(gui_handle_query(HANDLE.uicontrol,'tag','*beta slider_edit'),'string','1')

    ui_han=HANDLE.uicontrol;
    funk_han = gui_handle_query(ui_han,'tag','*Funktionsname*');
    funk_name = get(funk_han,'string');
    
    parallel = get(gui_handle_query(ui_han,'tag','*parallel value*'),'value');
    iterationen = get(gui_handle_query(ui_han,'tag','*iterations value*'),'value');

    
    niveaus = get(gui_handle_query(ui_han,'tag','*beta_number value*'),'value');
    gui_set_userdata(surf_pvert_han,'niveaus',niveaus);
    
    grenz_han = gui_handle_query(ui_han,'tag','*edit_grenz*');
    x_min = str2num(get(gui_handle_query(grenz_han,'tag','*x_min*'),'string'));
    x_max = str2num(get(gui_handle_query(grenz_han,'tag','*x_max*'),'string'));
    y_min = str2num(get(gui_handle_query(grenz_han,'tag','*y_min*'),'string'));
    y_max = str2num(get(gui_handle_query(grenz_han,'tag','*y_max*'),'string'));

    grenzen = [x_min, y_min; x_max, y_max];
    gui_set_userdata(surf_simtemp_han,'grenzen',grenzen);    
    set(gui_handle_query(HANDLE.uicontrol,'tag','*upper_right2*'),'enable','off')
    set(gui_handle_query(HANDLE.uicontrol,'tag','*upper_right3*'),'enable','off')

    pause(0.1)
    tic
%    keyboard
%    switch niveaus
%    case 5
%       load beta_5 xy_alle p_alle beta_alle vert temp;
%   case 1
%     load beta_1 xy_alle p_alle beta_alle vert temp;
% case 10
%     load beta_10 xy_alle p_alle beta_alle vert temp;
% otherwise
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%      
    [xy_alle, p_alle, beta_alle, vert, temp]=metropolis_fortran(funk_name, grenzen, parallel, iterationen, niveaus);
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%  
    %end
    %keyboard
    
    toc
    %save beta_10 xy_alle p_alle beta_alle vert temp
    
    lang = sum(vert);
    xy_alle = xy_alle(round(lang/2):end,:);
    p_alle = p_alle(round(lang/2):end,:);
    beta_alle = beta_alle(round(lang/2):end,:);  
    
    hx = reshape(xy_alle(:,1:2:end),[],1);
    hy = reshape(xy_alle(:,2:2:end),[],1);
    clear xy_alle
    xy_alle = [hx,hy];
    p_alle = reshape(p_alle,[],1);
    beta_alle = reshape(beta_alle,[],1);

    set(gui_handle_query(HANDLE.uicontrol,'tag','*upper_right2*'),'enable','on')
    set(gui_handle_query(HANDLE.uicontrol,'tag','*upper_right3*'),'enable','on')

    set(gui_handle_query(HANDLE.uicontrol,'tag','*smooth*'),'visible','off')

    han_surf=HANDLE.surface;
    surf_pvert_han = gui_handle_query(han_surf,'tag','*p_verteilung*');
    surf_simtemp_han = gui_handle_query(han_surf,'tag','*sim_temp*');
    
    gui_set_userdata(surf_pvert_han,'beta',temp)
    gui_set_userdata(surf_simtemp_han,'xy',xy_alle,'p',p_alle,'beta',beta_alle)
        
    set(gui_handle_query(HANDLE.uicontrol,'tag','*upper_right4*'),'enable','on')
    set(gui_handle_query(HANDLE.uicontrol,'tag','*upper_right2*'),'enable','on')
    
    set(gui_handle_query((HANDLE.uicontrol),'tag','*results*'),'enable','off')
    set(gui_handle_query(HANDLE.uicontrol,'tag','*beta slider'),'max',length(temp))
case 'exp_verteilung'
    han_surf = HANDLE.surface;
    surf_pvert_han = gui_handle_query(han_surf,'tag','*p_verteilung*');
    prob = gui_get_userdata(surf_pvert_han,'z_data');
    temp = gui_get_userdata(surf_pvert_han,'beta');
    temp_nummer = get(gcbo,'value');
    set(surf_pvert_han,'facecolor','texturemap','zdata',prob.^temp(temp_nummer),'cdata',prob.^temp(temp_nummer))
    set(gui_handle_query(HANDLE.uicontrol,'tag','*beta value*'),'enable','on','string',num2str(temp(temp_nummer)));
    
case 'sim_tempering'

    eval([func_name,' ','wahr_verteilung'])
    eval([func_name,' ','unsichtbar'])

    gui_set_userdata(gui_handle_query(HANDLE.uicontrol,'tag','*beta slider*'),'cbaction','sim_temp_beta')

    alle_handle=[HANDLE.axes,HANDLE.surface,HANDLE.line,HANDLE.patch];
    set(gui_handle_query((alle_handle),'tag','*sim_temp*'),'visible','on')   
    axes(gui_handle_query((HANDLE.axes),'tag','*sim_temp*'))
    
    
    han_surf=HANDLE.surface;
    surf_pvert_han = gui_handle_query(han_surf,'tag','*p_verteilung*');
    surf_simtemp_han = gui_handle_query(han_surf,'tag','*sim_temp*');

    xx=gui_get_userdata(surf_pvert_han,'x_data');
    yy=gui_get_userdata(surf_pvert_han,'y_data');
    prob=gui_get_userdata(surf_pvert_han,'z_data');
    niveaus = get(gui_handle_query(HANDLE.uicontrol,'tag','*beta_number value*'),'value');

    set(surf_simtemp_han,'facecolor','texturemap','xdata',xx,'ydata',yy,'zdata',prob,'cdata',prob)
    colormap bone
    
    xy_alle = gui_get_userdata(surf_simtemp_han,'xy');
    p_alle = gui_get_userdata(surf_simtemp_han,'p');
    beta_alle = gui_get_userdata(surf_simtemp_han,'beta');
    niveaus = gui_get_userdata(surf_pvert_han,'niveaus');

    farbe=hsv(niveaus+1);
    sim_line_han = gui_handle_query(HANDLE.line,'tag','sim_temp_line');

    set(sim_line_han,'xdata',[],'ydata',[],'zdata',[])

    for i=niveaus:-1:1
        beta_i=find(beta_alle==i);
        set(sim_line_han(i),'xdata',xy_alle(beta_i,1),'ydata',xy_alle(beta_i,2),'zdata',exp(p_alle(beta_i)),'color',farbe(i,:))
    end
    
case 'sim_temp_beta'
    han_surf=HANDLE.surface;
    surf_pvert_han = gui_handle_query(han_surf,'tag','*p_verteilung*');
    surf_simtemp_han = gui_handle_query(han_surf,'tag','*sim_temp*');

    xx=gui_get_userdata(surf_pvert_han,'x_data');
    yy=gui_get_userdata(surf_pvert_han,'y_data');
    prob=gui_get_userdata(surf_pvert_han,'z_data');
    niveaus = get(gui_handle_query(HANDLE.uicontrol,'tag','*beta_number value*'),'value');

    set(surf_simtemp_han,'facecolor','texturemap','xdata',xx,'ydata',yy,'zdata',prob,'cdata',prob)
    colormap bone
    
    xy_alle = gui_get_userdata(surf_simtemp_han,'xy');
    p_alle = gui_get_userdata(surf_simtemp_han,'p');
    beta_alle = gui_get_userdata(surf_simtemp_han,'beta');
    niveaus = gui_get_userdata(surf_pvert_han,'niveaus');
    temp = gui_get_userdata(surf_pvert_han,'beta');
    temp_nummer = get(gui_handle_query(HANDLE.uicontrol,'tag','*beta slider'),'value');
    set(gui_handle_query(HANDLE.uicontrol,'tag','*beta value*'),'enable','on','string',num2str(temp(temp_nummer)));

    farbe=hsv(niveaus+1);
    sim_line_han = gui_handle_query(HANDLE.line,'tag','sim_temp_line');

    set(sim_line_han,'xdata',[],'ydata',[],'zdata',[])
    beta_wert = str2num(get(gui_handle_query(HANDLE.uicontrol,'tag','*beta slider_edit*'),'string'));

    beta_i=find(beta_alle==beta_wert);
    set(sim_line_han(1),'xdata',xy_alle(beta_i,1),'ydata',xy_alle(beta_i,2),'zdata',exp(p_alle(beta_i)),'color',farbe(beta_wert,:))
    
case 'beta_histogramm'
    
    alle_handle=[HANDLE.axes,HANDLE.surface,HANDLE.line,HANDLE.patch];
    han_surf=HANDLE.surface;
    surf_pvert_han = gui_handle_query(han_surf,'tag','*p_verteilung*');
    surf_simtemp_han = gui_handle_query(han_surf,'tag','*sim_temp*');
    
    set(gui_handle_query((alle_handle),'tag','*sim_temp*'),'visible','off')
    set(gui_handle_query((alle_handle),'tag','*p_verteilung*'),'visible','off')
    set(gui_handle_query((alle_handle),'tag','*hist_1d*'),'visible','off')
    set(gui_handle_query((alle_handle),'tag','*beta_hist*'),'visible','on')
    set(gui_handle_query(HANDLE.uicontrol,'tag','*ergebnisse*'),'visible','off') 

    axes(gui_handle_query((HANDLE.axes),'tag','*beta_hist*'))
    
    beta_alle = gui_get_userdata(surf_simtemp_han,'beta');
    niveaus = gui_get_userdata(surf_pvert_han,'niveaus');
    histo = hist(beta_alle,1:niveaus);

    ydata=[zeros(1,niveaus);histo;histo;zeros(1,niveaus)];
    xdata=[(1:niveaus)-0.4;(1:niveaus)-0.4;(1:niveaus)+0.4;(1:niveaus)+0.4];
    set(gui_handle_query(HANDLE.patch,'tag','*beta_hist*'),'xdata',xdata,'ydata',ydata,'facecolor','r')
    xlim([0,niveaus+1])

    
case 'd1_histogramm'
    
    han_surf=HANDLE.surface;
    surf_simtemp_han = gui_handle_query(han_surf,'tag','*sim_temp*');

    eval([func_name,' ','unsichtbar'])

    alle_handle=[HANDLE.axes,HANDLE.surface,HANDLE.line,HANDLE.patch];

    set(gui_handle_query((alle_handle),'tag','*hist_1d*'),'visible','on')
    set(gui_handle_query(HANDLE.uicontrol,'tag','*smooth*'),'visible','on') 
    set(gui_handle_query(HANDLE.uicontrol,'tag','*results*'),'enable','on') 

    axes(gui_handle_query((HANDLE.axes),'tag','*hist_1d1*'))
       
    xy_alle = gui_get_userdata(surf_simtemp_han,'xy');
    beta_alle = gui_get_userdata(surf_simtemp_han,'beta');

    grenzen = gui_get_userdata(surf_simtemp_han,'grenzen');
    hist_zellen=str2num(get(gui_handle_query(HANDLE.uicontrol,'tag','*hist-cells slider_edit*'),'string'));
    
    intervall = grenzen(2,:)-grenzen(1,:);
    x_vektor = ((grenzen(1,1)+intervall(1)/hist_zellen):(intervall(1)/hist_zellen):grenzen(2,1))-intervall(1)/hist_zellen/2;
    y_vektor = ((grenzen(1,2)+intervall(2)/hist_zellen):(intervall(2)/hist_zellen):grenzen(2,2))-intervall(2)/hist_zellen/2;

    beta_1 = find(beta_alle==1);
    
    histo_x = hist(xy_alle(beta_1,1),x_vektor);
    histo_y = hist(xy_alle(beta_1,2),y_vektor);
    
    breite_x = intervall(1)/hist_zellen/2;
    breite_y = intervall(2)/hist_zellen/2;

    ydata=[zeros(1,hist_zellen);histo_x;histo_x;zeros(1,hist_zellen)];
    xdata=[x_vektor-breite_x;x_vektor-breite_x;x_vektor+breite_x;x_vektor+breite_x];
    
    set(gui_handle_query(HANDLE.patch,'tag','*hist_1d1*'),'xdata',xdata,'ydata',ydata,'facecolor','r')
 
    xlabel('x','fontunits','normalized','fontsize',0.1);  
    ylabel('frequency','fontunits','normalized','fontsize',0.1);
    
    axes(gui_handle_query((HANDLE.axes),'tag','*hist_1d2*'))
    
    ydata=[zeros(1,hist_zellen);histo_y;histo_y;zeros(1,hist_zellen)];
    xdata=[y_vektor-breite_y;y_vektor-breite_y;y_vektor+breite_y;y_vektor+breite_y];
    
    set(gui_handle_query(HANDLE.patch,'tag','*hist_1d2*'),'xdata',xdata,'ydata',ydata,'facecolor','g')
    xlabel('y','fontunits','normalized','fontsize',0.1)  
    ylabel('frequency','fontunits','normalized','fontsize',0.1);


case 'smooth_histogramm'
    
    yx_data=get(gui_handle_query(HANDLE.patch,'tag','*hist_1d1*'),'ydata');
    yy_data=get(gui_handle_query(HANDLE.patch,'tag','*hist_1d2*'),'ydata');
    
    yx_data(:,2:end-1)=(yx_data(:,2:end-1)+yx_data(:,1:end-2)+yx_data(:,3:end))/3;
    yx_data(:,1)=(yx_data(:,1)+yx_data(:,2))/2;
    yx_data(:,end)=(yx_data(:,end)+yx_data(:,end-1))/2;
    
    yy_data(:,2:end-1)=(yy_data(:,2:end-1)+yy_data(:,1:end-2)+yy_data(:,3:end))/3;
    yy_data(:,1)=(yy_data(:,1)+yy_data(:,2))/2;
    yy_data(:,end)=(yy_data(:,end)+yy_data(:,end-1))/2;

    set(gui_handle_query(HANDLE.patch,'tag','*hist_1d1*'),'ydata',yx_data);
    set(gui_handle_query(HANDLE.patch,'tag','*hist_1d2*'),'ydata',yy_data);

    
    
    
case 'd2_histogramm'

    han_surf=HANDLE.surface;
    surf_simtemp_han = gui_handle_query(han_surf,'tag','*sim_temp*');
    surf_hist2d_han = gui_handle_query(han_surf,'tag','*hist_2d*');

    eval([func_name,' ','unsichtbar'])

    alle_handle=[HANDLE.axes,HANDLE.surface,HANDLE.line,HANDLE.patch];

    set(gui_handle_query((alle_handle),'tag','*hist_2d*'),'visible','on')       
    axes(gui_handle_query((HANDLE.axes),'tag','*hist_2d*'))
   
    xy_alle = gui_get_userdata(surf_simtemp_han,'xy');       
    beta_alle = gui_get_userdata(surf_simtemp_han,'beta');

    grenzen = gui_get_userdata(surf_simtemp_han,'grenzen');
    grenze_unten= grenzen(1,:);
    grenze_oben = grenzen(2,:);
    hist_zellen=str2num(get(gui_handle_query(HANDLE.uicontrol,'tag','*hist-cells slider_edit*'),'string'));
    
    intervall = grenzen(2,:)-grenzen(1,:);

    histo_2d = zeros(hist_zellen,hist_zellen);        
    beta_1 = find(beta_alle==1);
    
    for i=1:length(beta_1)
        index1_2d=1+floor(((xy_alle(beta_1(i),1)-grenze_unten(1)))*hist_zellen/intervall(1));
        index2_2d=1+floor(((xy_alle(beta_1(i),2)-grenze_unten(2)))*hist_zellen/intervall(2));                    
        histo_2d(index1_2d,index2_2d)=histo_2d(index1_2d,index2_2d)+1;
    end
    
    x_vektor = ((grenzen(1,1)+intervall(1)/hist_zellen):(intervall(1)/hist_zellen):grenzen(2,1))-intervall(1)/hist_zellen/2;
    y_vektor = ((grenzen(1,2)+intervall(2)/hist_zellen):(intervall(2)/hist_zellen):grenzen(2,2))-intervall(2)/hist_zellen/2;

    [xx,yy] = meshgrid(x_vektor,y_vektor);    
    set(surf_hist2d_han,'facecolor','texturemap','xdata',xx,'ydata',yy,'zdata',(histo_2d/sum(sum(histo_2d)))','cdata',(histo_2d/sum(sum(histo_2d)))')
    shading faceted
    colormap jet
    
case 'results'

    eval([func_name,' ','unsichtbar'])
    set(gui_handle_query(HANDLE.uicontrol,'tag','*ergebnisse*'),'string','')

    han_surf=HANDLE.surface;
    surf_simtemp_han = gui_handle_query(han_surf,'tag','*sim_temp*');

    alle_handle=[HANDLE.axes,HANDLE.surface,HANDLE.line,HANDLE.patch];

    set(gui_handle_query((alle_handle),'tag','*results*'),'visible','on')
    set(gui_handle_query((HANDLE.uicontrol),'tag','*results*'),'enable','on')

    pause(0.1)
    axes(gui_handle_query((HANDLE.axes),'tag','*results*'))


    xy_alle = gui_get_userdata(surf_simtemp_han,'xy');
    beta_alle = gui_get_userdata(surf_simtemp_han,'beta');

    grenzen = gui_get_userdata(surf_simtemp_han,'grenzen');
    hist_zellen=str2num(get(gui_handle_query(HANDLE.uicontrol,'tag','*hist-cells slider_edit*'),'string'));
    intervall = grenzen(2,:)-grenzen(1,:);
    x_vektor = ((grenzen(1,1)+intervall(1)/hist_zellen):(intervall(1)/hist_zellen):grenzen(2,1))-intervall(1)/hist_zellen/2;
    y_vektor = ((grenzen(1,2)+intervall(2)/hist_zellen):(intervall(2)/hist_zellen):grenzen(2,2))-intervall(2)/hist_zellen/2;

    beta_1 = find(beta_alle==1);
    
    yx_data=get(gui_handle_query(HANDLE.patch,'tag','*hist_1d1*'),'ydata');
    yy_data=get(gui_handle_query(HANDLE.patch,'tag','*hist_1d2*'),'ydata');
    
    histo_x = yx_data(2,:);
    histo_y = yy_data(2,:);
 
    
    x_minimum = (imregionalmin(histo_x));
    x_minimum(1) = 1; x_minimum(end) = 1;
    x_min_num = find(x_minimum);
    histo_x(1) = 2*histo_x(1);
    histo_x(end) = 2*histo_x(end);
    
    for i=1:length(x_min_num)-1
        x_peak(i) = sum(histo_x(x_min_num(i):x_min_num((i+1))))-histo_x(x_min_num(i))/2-histo_x(x_min_num(i+1))/2;
        histo_x2 = histo_x(x_min_num(i):x_min_num((i+1)));
        histo_x2(1) = histo_x2(1)/2;         
        histo_x2(end) = histo_x2(end)/2;
        
        x_vektor2 = x_vektor(x_min_num(i):x_min_num((i+1)));
        peak_gewicht_x(i) = sum(histo_x2)/sum(histo_x);
        if sum(histo_x2)>0
            peak_mittel_x(i) = sum((histo_x2.*x_vektor2))/sum(histo_x2);            
            peak_std_x(i) = sqrt(sum((x_vektor2.^2).*histo_x2)/sum(histo_x2)-peak_mittel_x(i)^2);
        end
    end
    
    
    [h1,h2]  = sort(peak_gewicht_x);
    h3 = fliplr(h2);
    h4 = h3(1:min(10,length(h3)));
    
    han_mx = gui_handle_query(HANDLE.uicontrol,'tag','*ergebnisse_mx*');
    han_sx = gui_handle_query(HANDLE.uicontrol,'tag','*ergebnisse_sx*');
    han_gx = gui_handle_query(HANDLE.uicontrol,'tag','*ergebnisse_gx*');
    
    for i=1:length(h4)
        if peak_gewicht_x(h4(i))>0
            set(han_mx(i),'string',num2str(round(1000*peak_mittel_x(h4(i)))/1000),'horizontalalignment','left');
            set(han_sx(i),'string',num2str(round(1000*peak_std_x(h4(i)))/1000),'horizontalalignment','left');
            set(han_gx(i),'string',num2str(round(1000*100*peak_gewicht_x(h4(i)))/1000),'horizontalalignment','left');
        end
    end
    
    set(gui_handle_query(HANDLE.uicontrol,'tag','*gewicht*'),'string','Weight (%):','fontsize',0.4,'horizontalalignment','left')
    set(gui_handle_query(HANDLE.uicontrol,'tag','*mittel*'),'string','Mean:','fontsize',0.4,'horizontalalignment','left')
    set(gui_handle_query(HANDLE.uicontrol,'tag','*stand*'),'string','Std. Dev.:','fontsize',0.4,'horizontalalignment','left')

    y_minimum = (imregionalmin(histo_y));
    y_minimum(1) = 1; y_minimum(end) = 1;
    y_min_num = find(y_minimum);
    histo_y(1) = 2*histo_y(1);
    histo_y(end) = 2*histo_y(end);
    
    for i=1:length(y_min_num)-1
        y_peak(i) = sum(histo_y(y_min_num(i):y_min_num((i+1))))-histo_y(y_min_num(i))/2-histo_y(y_min_num(i+1))/2;
        histo_y2 = histo_y(y_min_num(i):y_min_num((i+1)));
        histo_y2(1) = histo_y2(1)/2;         
        histo_y2(end) = histo_y2(end)/2;
        
        y_vektor2 = y_vektor(y_min_num(i):y_min_num((i+1)));
        peak_gewicht_y(i) = sum(histo_y2)/sum(histo_y);
        if sum(histo_y2)>0
            peak_mittel_y(i) = sum((histo_y2.*y_vektor2))/sum(histo_y2);            
            peak_std_y(i) = sqrt(sum((y_vektor2.^2).*histo_y2)/sum(histo_y2)-peak_mittel_y(i)^2);
        end
    end
    
    [h1,h2]  = sort(peak_gewicht_y);
    h3 = fliplr(h2);
    h4 = h3(1:min(10,length(h3)));
    
    han_my = gui_handle_query(HANDLE.uicontrol,'tag','*ergebnisse_my*');
    han_sy = gui_handle_query(HANDLE.uicontrol,'tag','*ergebnisse_sy*');
    han_gy = gui_handle_query(HANDLE.uicontrol,'tag','*ergebnisse_gy*');
    
    for i=1:length(h4)
        if peak_gewicht_y(h4(i))>0
            set(han_my(i),'string',num2str(round(1000*peak_mittel_y(h4(i)))/1000),'horizontalalignment','left');
            set(han_sy(i),'string',num2str(round(1000*peak_std_y(h4(i)))/1000),'horizontalalignment','left');
            set(han_gy(i),'string',num2str(round(1000*100*peak_gewicht_y(h4(i)))/1000),'horizontalalignment','left');
        end
    end
    
    set(gui_handle_query(HANDLE.uicontrol,'tag','*ergebnisse_hy*'),'foregroundcolor',[0,0.5,0])
    set(gui_handle_query(HANDLE.uicontrol,'tag','*ergebnisse_hx*'),'foregroundcolor',[1,0,0])

    set(gui_handle_query(HANDLE.uicontrol,'tag','*ergebnisse_hx*'),...
        'string','Statistical weight, mean value and standard deviation for x, ranked by weight')
    set(gui_handle_query(HANDLE.uicontrol,'tag','*ergebnisse_hy*'),...
        'string','Statistical weight, mean value and standard deviation for y, ranked by weight')

    set(gui_handle_query(HANDLE.uicontrol,'tag','*ergebnisse*'),'visible','on') 

case 'animation_points'
    
    gui_set_userdata(gui_handle_query(HANDLE.uicontrol,'tag','*stop*'),'stop',0)
    
    eval([func_name,' ','wahr_verteilung'])
    eval([func_name,' ','unsichtbar'])


    alle_handle=[HANDLE.uicontrol,HANDLE.axes,HANDLE.surface,HANDLE.line,HANDLE.patch];
    set(gui_handle_query((alle_handle),'tag','*stop*'),'enable','on') 
    pause(0.1)

    axes(gui_handle_query((HANDLE.axes),'tag','*anim_points*'))
        
    han_surf=HANDLE.surface;
    surf_pvert_han = gui_handle_query(han_surf,'tag','*p_verteilung*');
    surf_animpoints_han = gui_handle_query(han_surf,'tag','*anim_points*');
    surf_simtemp_han = gui_handle_query(han_surf,'tag','*sim_temp*');

    line_han=gui_handle_query(HANDLE.line,'tag','*anim_points_line*');

    xx=gui_get_userdata(surf_pvert_han,'x_data');
    yy=gui_get_userdata(surf_pvert_han,'y_data');
    prob=gui_get_userdata(surf_pvert_han,'z_data');
    niveaus = get(gui_handle_query(HANDLE.uicontrol,'tag','*beta_number value*'),'value');
    temp = gui_get_userdata(surf_pvert_han,'beta');

    set(surf_animpoints_han,'facecolor','texturemap','xdata',xx,'ydata',yy,'zdata',prob,'cdata',prob)
    set(gui_handle_query((alle_handle),'tag','*anim_points*'),'visible','on') 

    colormap gray
    
    xy_alle = gui_get_userdata(surf_simtemp_han,'xy');
    p_alle = gui_get_userdata(surf_simtemp_han,'p');
    beta_alle = gui_get_userdata(surf_simtemp_han,'beta');
    niveaus = gui_get_userdata(surf_pvert_han,'niveaus');

    farbe=hsv(niveaus+1);
    set(gui_handle_query((alle_handle),'tag','*exit*'),'enable','off') 
  
    i=1;

    while i<length(beta_alle) & gui_get_userdata(gui_handle_query(HANDLE.uicontrol,'tag','*stop*'),'stop')==0
        h1 = mod(beta_alle(i),niveaus+1);
        xdata = xy_alle(i,1);
        ydata = xy_alle(i,2);
        zdata = exp(p_alle(i))^temp(h1);
        set(line_han(1),'xdata',xdata,'ydata',ydata,'zdata',zdata,'color',farbe(h1,:));
        drawnow  
     i=i+1;
    end
    
    set(gui_handle_query((alle_handle),'tag','*stop*'),'enable','off') 
    set(gui_handle_query((alle_handle),'tag','*exit*'),'enable','on') 


case 'animation_steps'
    
    gui_set_userdata(gui_handle_query(HANDLE.uicontrol,'tag','*stop*'),'stop',0)
    
    eval([func_name,' ','wahr_verteilung'])
    eval([func_name,' ','unsichtbar'])


    alle_handle=[HANDLE.uicontrol,HANDLE.axes,HANDLE.surface,HANDLE.line,HANDLE.patch];
    set(gui_handle_query((alle_handle),'tag','*stop*'),'enable','on') 
    pause(0.1)

    axes(gui_handle_query((HANDLE.axes),'tag','*anim_steps*'))
        
    han_surf=HANDLE.surface;
    surf_pvert_han = gui_handle_query(han_surf,'tag','*p_verteilung*');
    surf_animsteps_han = gui_handle_query(han_surf,'tag','*anim_steps*');
    surf_simtemp_han = gui_handle_query(han_surf,'tag','*sim_temp*');

    line_han=gui_handle_query(HANDLE.line,'tag','*anim_steps_line*');

    xx=gui_get_userdata(surf_pvert_han,'x_data');
    yy=gui_get_userdata(surf_pvert_han,'y_data');
    prob=gui_get_userdata(surf_pvert_han,'z_data');
    niveaus = get(gui_handle_query(HANDLE.uicontrol,'tag','*beta_number value*'),'value');
    temp = gui_get_userdata(surf_pvert_han,'beta');

    set(surf_animsteps_han,'facecolor','texturemap','xdata',xx,'ydata',yy,'zdata',prob,'cdata',prob)
    set(gui_handle_query((alle_handle),'tag','*anim_steps*'),'visible','on') 

    colormap summer
    
    xy_alle = gui_get_userdata(surf_simtemp_han,'xy');
    p_alle = gui_get_userdata(surf_simtemp_han,'p');
    beta_alle = gui_get_userdata(surf_simtemp_han,'beta');
    niveaus = gui_get_userdata(surf_pvert_han,'niveaus');

    farbe=hsv(niveaus+1);
    set(gui_handle_query((alle_handle),'tag','*exit*'),'enable','off') 
    i=1;
    while i<length(beta_alle) & gui_get_userdata(gui_handle_query(HANDLE.uicontrol,'tag','*stop*'),'stop')==0
        h1 = max(mod(i,niveaus),1);
        h2 = mod(beta_alle(i),niveaus+1);
        h3 = max(i-50,1);
        h4 = [0.3,0.3+0.6*exp(p_alle(h3)),0.3]/max(max(prob));
        set(line_han(1),'xdata',xy_alle(i,1),'ydata',xy_alle(i,2),'zdata',exp(p_alle(i)),'color',farbe(h2,:));
        set(line_han(1),'xdata',xy_alle(h3,1),'ydata',xy_alle(h3,2),'zdata',exp(p_alle(h3)),'color',h4);

        drawnow  
     i=i+1;
    end
    
    set(gui_handle_query((alle_handle),'tag','*stop*'),'enable','off') 
    set(gui_handle_query((alle_handle),'tag','*exit*'),'enable','on') 

    
case 'unsichtbar'
      
    alle_handle=[HANDLE.uicontrol,HANDLE.axes,HANDLE.surface,HANDLE.line,HANDLE.patch];

    set(gui_handle_query((alle_handle),'tag','*sim_temp*'),'visible','off')
    set(gui_handle_query((alle_handle),'tag','*p_verteilung*'),'visible','off')
    set(gui_handle_query((alle_handle),'tag','*beta_hist*'),'visible','off')
    set(gui_handle_query((alle_handle),'tag','*hist_1d*'),'visible','off')
    set(gui_handle_query((alle_handle),'tag','*hist_2d*'),'visible','off')
    set(gui_handle_query((HANDLE.axes),'tag','*results*'),'visible','off')
    set(gui_handle_query((alle_handle),'tag','*ergebnisse*'),'visible','off') 
    set(gui_handle_query((alle_handle),'tag','*smooth*'),'visible','off') 
    set(gui_handle_query((HANDLE.uicontrol),'tag','*results*'),'enable','off')
    set(gui_handle_query((alle_handle),'tag','*anim_points*'),'visible','off') 
    set(gui_handle_query((alle_handle),'tag','*anim_steps*'),'visible','off') 

    pause(0.1)
    
case 'funk_callback'
    
    set(gui_handle_query(HANDLE.uicontrol,'tag','*upper_right4*'),'enable','off')
    set(gui_handle_query(HANDLE.uicontrol,'tag','*upper_right2*'),'enable','off')
    set(gui_handle_query(HANDLE.uicontrol,'tag','*p-distribution*'),'enable','on')
    
   
otherwise
    % ======================================================================
    % warnings if callback routine is not defined (keep this at the end)    
    % ======================================================================
    disp(['Callback not defined: ',action]);
    % ======================================================================
    
end